@@ -1,7 +1,7 @@
 from sqlalchemy.orm.properties import ColumnProperty
-from sqlalchemy.sql import expression
+from sqlalchemy.sql import expression, not_
 from sqlalchemy.sql.expression import ColumnClause, literal
-from sqlalchemy.types import TypeEngine
+from sqlalchemy.types import UserDefinedType
 from sqlalchemy.ext.compiler import compiles
 
 from utils import from_wkt
@@ -13,6 +13,8 @@ class SpatialElement(object):
     """Represents a geometry value."""
 
     def __str__(self):
+        if isinstance(self.desc, SpatialElement):
+            return self.desc.desc
         return self.desc
 
     def __repr__(self):
@@ -30,6 +32,8 @@ class SpatialElement(object):
         if isinstance(self, WKTSpatialElement):
             # for WKTSpatialElement we don't need to make a new query
             return self.desc 
+        elif isinstance(self.desc, WKTSpatialElement):
+            return self.desc.desc
         else:
             return session.scalar(self.wkt)       
 
@@ -134,23 +138,31 @@ class PersistentSpatialElement(SpatialElement):
             return self.desc.desc
         else:
             return None
+    
+    @property    
+    def geom_wkt(self):
+        if self.desc is not None and isinstance(self.desc, WKTSpatialElement):
+            return self.desc.desc
+        else:
+            return None
 
-class GeometryBase(TypeEngine):
+class GeometryBase(UserDefinedType):
     """Base Geometry column type for all spatial databases.
-    
-    Converts bind/result values to/from a generic Persistent value.
-    This is used as a base class and overridden into dialect specific
-    Persistent values.
     """
-    
+
     name = 'GEOMETRY'
-    
-    def __init__(self, dimension=2, srid=4326, spatial_index=True, **kwargs):
+
+    def __init__(self, dimension=2, srid=4326, spatial_index=True,
+                 wkt_internal=False, **kwargs):
         self.dimension = dimension
         self.srid = srid
         self.spatial_index = spatial_index
+        self.wkt_internal = wkt_internal
         self.kwargs = kwargs
         super(GeometryBase, self).__init__()
+
+    def get_col_spec(self):
+        return self.name
     
     def bind_processor(self, dialect):
         def process(value):
@@ -172,16 +184,11 @@ class GeometryBase(TypeEngine):
             else:
                 return value
         return process
-    
-    def _compiler_dispatch(self, *args):
-        """Required for the Cast() operator when used for the compilation
-        of DBSpatialElement"""
-        return self.name
 
     def adapt(self, cls, **kwargs):
         return cls(dimension=self.dimension, srid=self.srid,
                    spatial_index=self.spatial_index,
-                   **self.kwargs)
+                   wkt_internal=self.wkt_internal, **self.kwargs)
 
 # ORM integration
 
@@ -256,5 +263,11 @@ class SpatialComparator(ColumnProperty.ColumnComparator):
         
     # override the __eq__() operator (allows to use '==' on geometries)
     def __eq__(self, other): 
+        if other is None:
+            return self.op("IS")(None)
         return functions.equals(self, other)
     
+    def __ne__(self, other):
+        if other is None:
+            return self.op("IS NOT")(None)
+        return not_(functions.equals(self, other))
